@@ -54,21 +54,36 @@ sub load {
     $code = $self->{sqla}->select_field(table => 'carts', field => 'code', where => {name => $self->name, uid => $uid});
     
     unless ($code) {
+	$self->{id} = 0;
 	return;
     }
     $self->{id} = $code;
 
-    # build query for item retrieval
-    %specs = (fields => $self->{settings}->{fields} || 
-	      [qw/products.sku products.name cart_products.quantity/],
-	      join => $self->{settings}->{join} ||
-	      [qw/carts code=cart cart_products sku=sku products/],
-	      where => {'carts.name' => $self->name, uid => $uid});	      
+    $self->_populate;
+}
 
-    # retrieve items from database
-    $result = $self->{sqla}->select(%specs);
+=head2 load_by_id
 
-    $self->seed($result);
+Loads cart from database by specifying identifier.
+
+=cut
+
+sub load_by_id {
+    my ($self, $id) = @_;
+    my ($name);
+
+    # determine cart name
+    $name = $self->{sqla}->select_field(table => 'carts', field => 'code', where => {code => $id});
+
+    unless ($name) {
+	$self->{id} = 0;
+	return;
+    }
+
+    $self->{id} = $id;
+    $self->{name} = $name;
+
+    $self->_populate;
 }
 
 =head2 save
@@ -81,6 +96,24 @@ sub save {
     return 1;
 }
 
+sub _populate {
+    my ($self, %specs, $result);
+
+    $self = shift;
+
+    # build query for item retrieval
+    %specs = (fields => $self->{settings}->{fields} || 
+	      [qw/products.sku products.name cart_products.quantity/],
+	      join => $self->{settings}->{join} ||
+	      [qw/carts code=cart cart_products sku=sku products/],
+	      where => {'carts.code' => $self->{id}});	      
+
+    # retrieve items from database
+    $result = $self->{sqla}->select(%specs);
+
+    $self->seed($result);
+}
+
 sub _after_cart_add {
     my ($self, @args) = @_;
     my ($item, $record);
